changeset 906:47895e9cff74

fix MySQL label tests for mainline
author Alain Mazy <am@orthanc.team>
date Wed, 15 Apr 2026 08:34:39 +0200
parents 6e2e3e6651d4
children d379e803c138
files Tests/Tests.py
diffstat 1 files changed, 6 insertions(+), 6 deletions(-) [+]
line wrap: on
line diff
--- a/Tests/Tests.py	Tue Apr 14 21:07:50 2026 +0200
+++ b/Tests/Tests.py	Wed Apr 15 08:34:39 2026 +0200
@@ -10438,8 +10438,8 @@
             self.assertEqual(1, len(Execute([], 'All')))
             self.assertEqual(1, len(Execute([], 'Any')))
             # From 1.12.11, 'None' with an empty labels list means "list all resources without any labels"
-            # But this is currently only implemented in SQLite and PostgreSQL
-            if IsOrthancVersionAbove(_REMOTE, 1, 12, 11) and not HasMySQLIndexPlugin(_REMOTE) and not HasODBCIndexPlugin(_REMOTE): 
+            # But this is currently only implemented in SQLite and PostgreSQL (and in the mainline MySQL)
+            if IsOrthancVersionAbove(_REMOTE, 1, 12, 11) and (not HasMySQLIndexPlugin(_REMOTE) or IsPluginVersionAtLeast(_REMOTE, 'orthanc-mysql', 6, 0, 0)) and not HasODBCIndexPlugin(_REMOTE): 
                 self.assertEqual(0, len(Execute([], 'None')))
             else:
                 self.assertEqual(1, len(Execute([], 'None')))
@@ -10499,8 +10499,8 @@
             self.assertEqual(1, len(Execute([], 'All')))
             self.assertEqual(1, len(Execute([], 'Any')))
             # From 1.12.11, 'None' with an empty labels list means "list all resources without any labels"
-            # But this is currently only implemented in SQLite and PostgreSQL
-            if IsOrthancVersionAbove(_REMOTE, 1, 12, 11) and not HasMySQLIndexPlugin(_REMOTE) and not HasODBCIndexPlugin(_REMOTE): 
+            # But this is currently only implemented in SQLite and PostgreSQL (and in the mainline MySQL)
+            if IsOrthancVersionAbove(_REMOTE, 1, 12, 11) and (not HasMySQLIndexPlugin(_REMOTE) or IsPluginVersionAtLeast(_REMOTE, 'orthanc-mysql', 6, 0, 0)) and not HasODBCIndexPlugin(_REMOTE): 
                 self.assertEqual(0, len(Execute([], 'None')))
             else:
                 self.assertEqual(1, len(Execute([], 'None')))
@@ -10525,8 +10525,8 @@
             self.assertEqual(1, len(Execute([], 'All')))
             self.assertEqual(1, len(Execute([], 'Any')))
             # From 1.12.11, 'None' with an empty labels list means "list all resources without any labels"
-            # But this is currently only implemented in SQLite and PostgreSQL
-            if IsOrthancVersionAbove(_REMOTE, 1, 12, 11) and not HasMySQLIndexPlugin(_REMOTE) and not HasODBCIndexPlugin(_REMOTE): 
+            # But this is currently only implemented in SQLite and PostgreSQL (and in the mainline MySQL)
+            if IsOrthancVersionAbove(_REMOTE, 1, 12, 11) and (not HasMySQLIndexPlugin(_REMOTE) or IsPluginVersionAtLeast(_REMOTE, 'orthanc-mysql', 6, 0, 0)) and not HasODBCIndexPlugin(_REMOTE): 
                 self.assertEqual(0, len(Execute([], 'None')))
             else:
                 self.assertEqual(1, len(Execute([], 'None')))